==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Templater/Events/TemplaterPreRenderEvent.php <==
<?php
namespace Claromentis\Core\Templater\Events;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Core\Templater\TemplateRunner;
class TemplaterPreRenderEvent extends Event
{
    
    
    
    
    protected $args;
    
    
    
    
    protected $template_path;
    
    
    
    
    protected $datasources;
    
    
    
    
    protected $template_runner;
    
    
    
    
    protected $vi;
    
    
    
    
    
    
    
    
    
    
    public function __construct(string $_6fa293f4a9baf5f0e16be8c4e2c6434b, array $args, array $_2142cfafde78da7f579e7923dee6f777, TemplateRunner $_4833b93dc0784db3ec4a01e7a085ffdd = null, string $_d0170fbf6fa5496b6773d02ef9e8189b = null)
    {
        $this->template_path = $_6fa293f4a9baf5f0e16be8c4e2c6434b;
        $this->args = $args;
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
        $this->template_runner = $_4833b93dc0784db3ec4a01e7a085ffdd;
        $this->vi = $_d0170fbf6fa5496b6773d02ef9e8189b;
    }
    
    
    
    
    public function GetArgs() : array
    {
        return $this->args;
    }
    
    
    
    
    public function SetArgs(array $args)
    {
        $this->args = $args;
    }
    
    
    
    
    public function GetDatasources() : array
    {
        return $this->datasources;
    }
    
    
    
    
    public function SetDatasources(array $_2142cfafde78da7f579e7923dee6f777)
    {
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
    }
    
    
    
    
    public function GetTemplatePath() : string
    {
        return $this->template_path;
    }
    
    
    
    
    public function SetTemplatePath(string $_6fa293f4a9baf5f0e16be8c4e2c6434b)
    {
        $this->template_path = $_6fa293f4a9baf5f0e16be8c4e2c6434b;
    }
    
    
    
    
    public function GetTemplateRunner()
    {
        return $this->template_runner;
    }
    
    
    
    
    public function SetTemplateRunner(TemplateRunner $_4833b93dc0784db3ec4a01e7a085ffdd)
    {
        $this->template_runner = $_4833b93dc0784db3ec4a01e7a085ffdd;
    }
    
    
    
    
    public function GetVi()
    {
        return $this->vi;
    }
    
    
    
    
    public function SetVi(string $_d0170fbf6fa5496b6773d02ef9e8189b)
    {
        $this->vi = $_d0170fbf6fa5496b6773d02ef9e8189b;
    }
    
    
    
    
    
    
    public function GetAll()
    {
        return [$this->template_path, $this->args, $this->datasources, $this->template_runner, $this->vi];
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Templater/Events/TemplaterPreRenderEvent.php <==
<?php
namespace Claromentis\Core\Templater\Events;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array();
use Claromentis\Core\Event\Event;
use Claromentis\Core\Templater\TemplateRunner;
class TemplaterPreRenderEvent extends Event
{
    
    
    
    
    protected $args;
    
    
    
    
    protected $template_path;
    
    
    
    
    protected $datasources;
    
    
    
    
    protected $template_runner;
    
    
    
    
    protected $vi;
    
    
    
    
    
    
    
    
    
    
    public function __construct(string $_6fa293f4a9baf5f0e16be8c4e2c6434b, array $args, array $_2142cfafde78da7f579e7923dee6f777, TemplateRunner $_4833b93dc0784db3ec4a01e7a085ffdd = null, string $_d0170fbf6fa5496b6773d02ef9e8189b = null)
    {
        $this->template_path = $_6fa293f4a9baf5f0e16be8c4e2c6434b;
        $this->args = $args;
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
        $this->template_runner = $_4833b93dc0784db3ec4a01e7a085ffdd;
        $this->vi = $_d0170fbf6fa5496b6773d02ef9e8189b;
    }
    
    
    
    
    public function GetArgs() : array
    {
        return $this->args;
    }
    
    
    
    
    public function SetArgs(array $args)
    {
        $this->args = $args;
    }
    
    
    
    
    public function GetDatasources() : array
    {
        return $this->datasources;
    }
    
    
    
    
    public function SetDatasources(array $_2142cfafde78da7f579e7923dee6f777)
    {
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
    }
    
    
    
    
    public function GetTemplatePath() : string
    {
        return $this->template_path;
    }
    
    
    
    
    public function SetTemplatePath(string $_6fa293f4a9baf5f0e16be8c4e2c6434b)
    {
        $this->template_path = $_6fa293f4a9baf5f0e16be8c4e2c6434b;
    }
    
    
    
    
    public function GetTemplateRunner()
    {
        return $this->template_runner;
    }
    
    
    
    
    public function SetTemplateRunner(TemplateRunner $_4833b93dc0784db3ec4a01e7a085ffdd)
    {
        $this->template_runner = $_4833b93dc0784db3ec4a01e7a085ffdd;
    }
    
    
    
    
    public function GetVi()
    {
        return $this->vi;
    }
    
    
    
    
    public function SetVi(string $_d0170fbf6fa5496b6773d02ef9e8189b)
    {
        $this->vi = $_d0170fbf6fa5496b6773d02ef9e8189b;
    }
    
    
    
    
    
    
    public function GetAll()
    {
        return [$this->template_path, $this->args, $this->datasources, $this->template_runner, $this->vi];
    }
}
